@@ -3,14 +3,10 @@ from typing import override, Type, TYPE_CHECKING, Any, Callable, Optional
 
 if TYPE_CHECKING:
     from ormlambda import Table
-    from ormlambda.components.select import ISelect
     from ormlambda.components.where.abstract_where import AbstractWhere
     from ormlambda.common.interfaces.IStatements import OrderType
     from ormlambda.common.interfaces import IQuery, IRepositoryBase, IStatements_two_generic
-    
-    from ormlambda.databases.my_sql.clauses.select import SelectQuery
-    from ormlambda.databases.my_sql.clauses.count import CountQuery
-
+    from ormlambda.common.interfaces.IRepositoryBase import TypeExists
 
 from ormlambda import AbstractSQLStatements
 from .clauses import DeleteQuery
@@ -19,14 +15,15 @@ from .clauses import JoinSelector
 from .clauses import LimitQuery
 from .clauses import OffsetQuery
 from .clauses import OrderQuery
-from .clauses import SelectQuery
+from .clauses.select import Select
+
 from .clauses import UpsertQuery
 from .clauses import UpdateQuery
 from .clauses import WhereCondition
-from .clauses import CountQuery
-
-from mysql.connector import MySQLConnection
+from .clauses import Count
+from .clauses import GroupBy
 
+from mysql.connector import MySQLConnection, errors, errorcode
 
 
 import inspect
@@ -35,7 +32,6 @@ from ormlambda.utils import ForeignKey, Table
 from ormlambda.common.enums import JoinType
 
 
-
 class MySQLStatements[T: Table](AbstractSQLStatements[T, MySQLConnection]):
     def __init__(self, model: T, repository: IRepositoryBase[MySQLConnection]) -> None:
         super().__init__(model, repository=repository)
@@ -46,9 +42,26 @@ class MySQLStatements[T: Table](AbstractSQLStatements[T, MySQLConnection]):
         return self._repository
 
     @override
-    def create_table(self) -> None:
-        if not self._repository.table_exists(self._model.__table_name__):
-            self._repository.execute(self._model.create_table_query())
+    def create_table(self, if_exists: TypeExists = "fail") -> None:
+        name: str = self._model.__table_name__
+        if self._repository.table_exists(name):
+            if if_exists == "replace":
+                self._repository.drop_table(name)
+
+            elif if_exists == "fail":
+                raise errors.ProgrammingError(msg=f"Table '{self._model.__table_name__}' already exists", errno=errorcode.ER_TABLE_EXISTS_ERROR)
+
+            elif if_exists == "append":
+                counter: int = 0
+                char: str = ""
+                while self._repository.table_exists(name + char):
+                    counter += 1
+                    char = f"_{counter}"
+                name += char
+                self._model.__table_name__ = name
+
+        query = self._model.create_table_query()
+        self._repository.execute(query)
         return None
 
     @override
@@ -113,10 +126,10 @@ class MySQLStatements[T: Table](AbstractSQLStatements[T, MySQLConnection]):
         return self
 
     @override
-    def count(self) -> int:
-        count_select: IQuery = CountQuery(self._model)
+    def count(self, selection: Callable[[T], tuple] = lambda x: "*") -> int:
+        count_select: IQuery = Select[T](self._model, lambda x: Count[T](self._model, selection))
         self._query_list["select"].append(count_select)
-        query = self.build()
+        query = self._build()
         return self.repository.read_sql(query)[0][0]
 
     @override
@@ -149,10 +162,10 @@ class MySQLStatements[T: Table](AbstractSQLStatements[T, MySQLConnection]):
             if flavour:
                 return result
             return () if not result else result[0]
-        select: ISelect = SelectQuery(self._model, select_lambda=selector, by=by)
+        select = Select[T](self._model, lambda_query=selector, by=by, alias=False)
         self._query_list["select"].append(select)
 
-        query: str = self.build()
+        query: str = self._build()
         if flavour:
             result = self._return_flavour(query, flavour)
             if issubclass(flavour, tuple) and isinstance(selector(self._model), property):
@@ -178,12 +191,17 @@ class MySQLStatements[T: Table](AbstractSQLStatements[T, MySQLConnection]):
         return tuple([res[0] for res in response])
 
     @override
-    def build(self) -> str:
+    def group_by[TRepo, *Ts](self, column: Callable[[T], TRepo], select_query: Callable[[T], tuple[*Ts]]) -> tuple[tuple[*Ts]]:
+        return GroupBy[T, TRepo, tuple[*Ts]](self._model, column, select_query)
+
+    @override
+    def _build(self) -> str:
         query: str = ""
 
-        self.__create_necessary_inner_join()
+        # self.__create_necessary_inner_join()
         for x in self.__order__:
-            if sub_query := self._query_list.get(x, None):
+            sub_query: Optional[list[IQuery]] = self._query_list.get(x, None)
+            if sub_query is not None:
                 if isinstance(sub_query[0], WhereCondition):
                     query_ = self.__build_where_clause(sub_query)
 
@@ -209,19 +227,3 @@ class MySQLStatements[T: Table](AbstractSQLStatements[T, MySQLConnection]):
             and_, clause = q.split(" ", maxsplit=1)
             query += f" {and_} ({clause})"
         return query
-
-    def __create_necessary_inner_join(self) -> None:
-        # When we applied filters in any table that we wont select any column, we need to add manually all neccessary joins to achieve positive result.
-        if "where" not in self._query_list:
-            return None
-
-        where: AbstractWhere = self._query_list["where"][0]
-        involved_tables = where.get_involved_tables()
-
-        select: ISelect = self._query_list["select"][0]
-        if not involved_tables or (set(involved_tables) == set(select.tables_heritage)):
-            return None
-
-        for l_tbl, r_tbl in involved_tables:
-            # FIXME [ ]: Checked what function was called by the self.join method before the change
-            self.join(l_tbl, r_tbl, by="INNER JOIN")
